@@ -7,7 +7,7 @@
 #### movMF: An R Package for Fitting Mixtures of von Mises-Fisher Distributions
 #### http://cran.r-project.org/web/packages/movMF/vignettes/movMF.pdf
 ################################
-bic.mixvmf <- function(x, A = 3) {
+bic.mixvmf <- function(x, A = 3, n.start = 20) {
   ## x contains the data
   ## A is the maximum number of clusters, set to 3 by default
   runtime <- proc.time()
@@ -17,7 +17,7 @@ bic.mixvmf <- function(x, A = 3) {
   mod <- vmf(x)
   bic[1] <-  - 2 * mod$loglik+ p * logn  ## BIC assuming one cluster
   for (vim in 2:A) {
-    a <- mix.vmf(x, vim)  ## model based clustering for some possible clusters
+    a <- mix.vmf(x, vim, n.start = n.start)  ## model based clustering for some possible clusters
     bic[vim] <-  -2 * a$loglik + ( (vim - 1) + vim * p ) * logn
   }  ## BIC for a range of different clusters
   runtime <- proc.time() - runtime
